@@ -1,4 +1,4 @@
-ascii.survdiff <- function (x, include.rownames = TRUE, include.colnames = TRUE, rownames = NULL, colnames = NULL, format = "f", digits = 2, decimal.mark = ".", na.print = "", caption = "", caption.level = "", width = 0, frame = "", grid = "", valign = "", header = TRUE, footer = FALSE, align = "", col.width = 1, style = "", cgroup = NULL, n.cgroup = NULL, calign = "", cvalign = "", cstyle = "", rgroup = NULL, n.rgroup = NULL, ralign = "", rvalign = "", rstyle = "", ...){
+ascii.survdiff <- function (x, include.rownames = TRUE, include.colnames = TRUE, rownames = NULL, colnames = NULL, format = "f", digits = 2, decimal.mark = ".", na.print = "", caption = "", caption.level = "", width = 0, frame = "", grid = "", valign = "", header = TRUE, footer = FALSE, align = "", col.width = 1, style = "", tgroup = NULL, n.tgroup = NULL, talign = "", tvalign = "", tstyle = "", bgroup = NULL, n.bgroup = NULL, balign = "", bvalign = "", bstyle = "", lgroup = NULL, n.lgroup = NULL, lalign = "", lvalign = "", lstyle = "", rgroup = NULL, n.rgroup = NULL, ralign = "", rvalign = "", rstyle = "", ...){
     # From print.survdiff
     if (length(x$n) == 1) {
         z <- sign(x$exp - x$obs) * sqrt(x$chisq)
@@ -30,8 +30,13 @@ ascii.survdiff <- function (x, include.rownames = TRUE, include.colnames = TRUE,
       format = format, digits = digits, decimal.mark = decimal.mark, na.print = na.print,
       caption = caption, caption.level = caption.level, width = width, frame = frame,
       grid = grid, valign = valign, header = header, footer = footer, align = align,
-      col.width = col.width, style = style, cgroup = cgroup, n.cgroup = n.cgroup,
-      calign = calign, cvalign = cvalign, cstyle = cstyle,
+      col.width = col.width, style = style,
+      tgroup = tgroup, n.tgroup = n.tgroup, talign = talign,
+      tvalign = tvalign, tstyle = tstyle,
+      bgroup = bgroup, n.bgroup = n.bgroup, balign = balign,
+      bvalign = bvalign, bstyle = bstyle,
+      lgroup = lgroup, n.lgroup = n.lgroup, lalign = lalign,
+      lvalign = lvalign, lstyle = lstyle,
       rgroup = rgroup, n.rgroup = n.rgroup, ralign = ralign,
       rvalign = rvalign, rstyle = rstyle)
   class(obj) <- c("ascii", "proto", "environment")
@@ -39,7 +44,7 @@ ascii.survdiff <- function (x, include.rownames = TRUE, include.colnames = TRUE,
 }
 
 # from xtable package
-ascii.coxph <- function (x, include.rownames = TRUE, include.colnames = TRUE, rownames = NULL, colnames = NULL, format = "f", digits = 2, decimal.mark = ".", na.print = "", caption = "", caption.level = "", width = 0, frame = "", grid = "", valign = "", header = TRUE, footer = FALSE, align = "", col.width = 1, style = "", cgroup = NULL, n.cgroup = NULL, calign = "", cvalign = "", cstyle = "", rgroup = NULL, n.rgroup = NULL, ralign = "", rvalign = "", rstyle = "", ...){
+ascii.coxph <- function (x, include.rownames = TRUE, include.colnames = TRUE, rownames = NULL, colnames = NULL, format = "f", digits = 2, decimal.mark = ".", na.print = "", caption = "", caption.level = "", width = 0, frame = "", grid = "", valign = "", header = TRUE, footer = FALSE, align = "", col.width = 1, style = "", tgroup = NULL, n.tgroup = NULL, talign = "", tvalign = "", tstyle = "", bgroup = NULL, n.bgroup = NULL, balign = "", bvalign = "", bstyle = "", lgroup = NULL, n.lgroup = NULL, lalign = "", lvalign = "", lstyle = "", rgroup = NULL, n.rgroup = NULL, ralign = "", rvalign = "", rstyle = "", ...){
 
     cox <- x
     beta <- cox$coef
@@ -52,8 +57,13 @@ ascii.coxph <- function (x, include.rownames = TRUE, include.colnames = TRUE, ro
       format = format, digits = digits, decimal.mark = decimal.mark, na.print = na.print,
       caption = caption, caption.level = caption.level, width = width, frame = frame,
       grid = grid, valign = valign, header = header, footer = footer, align = align,
-      col.width = col.width, style = style, cgroup = cgroup, n.cgroup = n.cgroup,
-      calign = calign, cvalign = cvalign, cstyle = cstyle,
+      col.width = col.width, style = style,
+      tgroup = tgroup, n.tgroup = n.tgroup, talign = talign,
+      tvalign = tvalign, tstyle = tstyle,
+      bgroup = bgroup, n.bgroup = n.bgroup, balign = balign,
+      bvalign = bvalign, bstyle = bstyle,
+      lgroup = lgroup, n.lgroup = n.lgroup, lalign = lalign,
+      lvalign = lvalign, lstyle = lstyle,
       rgroup = rgroup, n.rgroup = n.rgroup, ralign = ralign,
       rvalign = rvalign, rstyle = rstyle)
   class(obj) <- c("ascii", "proto", "environment")
